@@ -53,13 +53,6 @@ static __inline__ int forceReadSector(Fs_t *This, char *buf, unsigned int off,
 }
 
 
-static __inline__ int writeSector(Fs_t *This, char *buf, unsigned int off,
-				  size_t size)
-{
-	return WRITES(This->Next, buf, sectorsToBytes((Stream_t*)This, off), 
-				  size << This->sectorShift);
-}
-
 static __inline__ int forceWriteSector(Fs_t *This, char *buf, unsigned int off,
 				       size_t size)
 {
@@ -70,7 +63,8 @@ static __inline__ int forceWriteSector(Fs_t *This, char *buf, unsigned int off,
 
 static FatMap_t *GetFatMap(Fs_t *Stream)
 {
-	int nr_entries,i;
+	size_t nr_entries;
+	size_t i;
 	FatMap_t *map;
 
 	Stream->fat_error = 0;
@@ -460,9 +454,14 @@ void fat_write(Fs_t *This)
 		/* initialize info sector */
 		InfoSector_t *infoSector;
 		infoSector = (InfoSector_t *) safe_malloc(This->sector_size);
+		if(forceReadSector(This, (char *)infoSector,
+				   This->infoSectorLoc, 1) !=
+		   (signed int) This->sector_size) {
+			fprintf(stderr,"Trouble reading the info sector\n");
+			memset(infoSector->filler1, 0, sizeof(infoSector->filler1));
+			memset(infoSector->filler2, 0, sizeof(infoSector->filler2));
+		}
 		set_dword(infoSector->signature1, INFOSECT_SIGNATURE1);
-		memset(infoSector->filler1, 0, sizeof(infoSector->filler1));
-		memset(infoSector->filler2, 0, sizeof(infoSector->filler2));
 		set_dword(infoSector->signature2, INFOSECT_SIGNATURE2);
 		set_dword(infoSector->pos, This->last);
 		set_dword(infoSector->count, This->freeSpace);
@@ -672,7 +671,7 @@ static int check_media_type(Fs_t *This, union bootsector *boot,
 static int fat_32_read(Fs_t *This, union bootsector *boot, 
 		       unsigned int tot_sectors)
 {
-	int size;
+	size_t size;
 
 	This->fat_len = DWORD(ext.fat32.bigFat);
 	This->writeAllFats = !(boot->boot.ext.fat32.extFlags[0] & 0x80);
